package org.brownell.notdom;

import java.util.*;

/**
 * Provides a streamlined (compared to DOM) representation of an XML element.
 * Simplifications include: <ul>
 *	<li> This uses the JDK 1.2 "Collections" framework, reducing the
 *	cost associated with learning and using extra classes. </li>
 *	<li> These elements don't provide access to parent or sibling nodes,
 *	or to any "owning" document, only children.  This speeds up tree
 *	manipulations, and also enables sharing of nodes. </li>
 *	<li> The element "is" the list of its children; no separate node
 *	needs to be accessed, simplifying coding and representation.</li> 
 *	<li> There are no special "Text" or "CDATA" nodes; they are both
 *	represented as strings. </li>
 *	<li> There is no special node type for attributes; their values
 *	are strings, and empty strings are only returned when the attribute
 *	truly has such a value (null means no value). </li>
 *	<li> The Java type system is used directly. </li>
 *	<li> There's no special name-based iterator.
 *		</li>
 *	</ul>
 */
public class Element extends ArrayList
{
    private HashMap	attributes;
    private String	tag;

    /**
     */
    public String	getTag ()
    {
	return tag;
    }

    /**
     */
    public void setAttribute (String key, String value)
    {
	if (attributes == null)
	    attributes = new HashMap ();	// XXX params
	attributes.set (key, value);
    }

    /**
     */
    public String getAttribute (String key)
    {
	if (attributes == null)
	    return null;
	return attributes.get (key);
    }

    /**
     */
    public void removeAttribute (String key)
    {
    }

    /**
     */
    public void normalize (boolean deep)
    {
    }
}
