/*
 * Copyright (c) 1999 by David Brownell.  All Rights Reserved.
 *
 * This program is open source software; you may use, copy, modify, and
 * redistribute it under the terms of the LICENSE with which it was
 * originally distributed.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * LICENSE for more details.
 */

package org.brownell.xml;

import org.xml.sax.HandlerBase;
import org.xml.sax.SAXException;
import org.xml.sax.misc.*;


/**
 * This class provides extends the SAX base handler class to support the
 * SAX 2 Lexical and Declaration handlers.  All the handler methods do
 * is return; except that the HandlerBase class handles fatal errors by
 * throwing an exception.
 *
 * @author David Brownell (db@post.harvard.edu)
 * @version 1.1 (23 June 1999)
 */
public class DefaultHandler extends HandlerBase 
    implements LexicalHandler, DeclHandler
{
    /** Constructs a handler which ignores all parsing events. */
    public DefaultHandler () { }

    // SAX2 LexicalHandler

    /** <b>SAX2</b>:  called before parsing CDATA characters */
    public void startCDATA ()
    throws SAXException
	{}

    /** <b>SAX2</b>:  called after parsing CDATA characters */
    public void endCDATA ()
    throws SAXException
	{}

    /** <b>SAX2</b>:  called when the doctype is partially parsed */
    public void startDTD (String root, String pubid, String sysid)
    throws SAXException
	{}

    /** <b>SAX2</b>:  called after the doctype is parsed */
    public void endDTD ()
    throws SAXException
	{}

    /** <b>SAX2</b>:  called before parsing an entity */
    public void startEntity (String name)
    throws SAXException
	{}

    /** <b>SAX2</b>:  called after parsing an entity */
    public void endEntity (String name)
    throws SAXException
	{}

    /** <b>SAX2</b>:  called when comments are parsed */
    public void comment (char buf [], int off, int len)
    throws SAXException
	{ }

    // SAX2 DeclHandler

    /** <b>SAX2</b>:  called on attribute declarations */
    public void attributeDecl (String element, String name,
	    String type, String defaultType, String defaltValue)
    throws SAXException
	{}

    /** <b>SAX2</b>:  called on element declarations */
    public void elementDecl (String name, String model)
    throws SAXException
	{}

    /** <b>SAX2</b>:  called on external entity declarations */
    public void externalEntityDecl (String name, String pubid, String sysid)
    throws SAXException
	{}

    /** <b>SAX2</b>:  called on internal entity declarations */
    public void internalEntityDecl (String name, String value)
    throws SAXException
	{}
}
